@@ -80,9 +80,11 @@ struct GpkCheckUpdatePrivate
 	GConfClient		*gconf_client;
 	guint			 number_updates_critical_last_shown;
 	NotifyNotification	*notification_updates_available;
+	NotifyNotification	*notification_error;
 	EggDbusMonitor		*dbus_monitor_viewer;
 	guint			 updates_changed_id;
 	GCancellable		*cancellable;
+	PkError			*error_code;
 };
 
 G_DEFINE_TYPE (GpkCheckUpdate, gpk_check_update, G_TYPE_OBJECT)
@@ -174,50 +176,11 @@ gpk_check_update_show_preferences_cb (GtkMenuItem *item, GpkCheckUpdate *cupdate
 		egg_warning ("Couldn't execute command: %s", command);
 }
 
-/**
- * gpk_check_update_about_dialog_url_cb:
- **/
-static void
-gpk_check_update_about_dialog_url_cb (GtkAboutDialog *about, const char *address, gpointer data)
-{
-	GError *error = NULL;
-	gboolean ret;
-	GdkScreen *gscreen;
-	GtkWidget *error_dialog;
-	gchar *url;
-	gchar *protocol = (gchar*) data;
-
-	if (protocol != NULL)
-		url = g_strconcat (protocol, address, NULL);
-	else
-		url = g_strdup (address);
-
-	gscreen = gtk_window_get_screen (GTK_WINDOW (about));
-
-	ret = gtk_show_uri (gscreen, url, gtk_get_current_event_time (), &error);
-
-	if (!ret) {
-		error_dialog = gtk_message_dialog_new (GTK_WINDOW (about),
-						       GTK_DIALOG_MODAL,
-						       GTK_MESSAGE_INFO,
-						       GTK_BUTTONS_OK,
-						       /* TRANSLATORS: normally a packaging error, cannot launch link */
-						       _("Failed to show url"));
-		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (error_dialog),
-							  "%s", error->message);
-		gtk_dialog_run (GTK_DIALOG (error_dialog));
-		gtk_widget_destroy (error_dialog);
-		g_error_free (error);
-	}
-
-	g_free (url);
-}
-
 /**
  * gpk_check_update_show_about_cb:
  **/
 static void
-gpk_check_update_show_about_cb (GtkMenuItem *item, gpointer data)
+gpk_check_update_show_about_cb (GtkMenuItem *item, GpkCheckUpdate *icon)
 {
 	const char *authors[] = {
 		"Richard Hughes <richard@hughsie.com>",
@@ -250,9 +213,6 @@ gpk_check_update_show_about_cb (GtkMenuItem *item, gpointer data)
 	license_trans = g_strconcat (_(license[0]), "\n\n", _(license[1]), "\n\n",
 				     _(license[2]), "\n\n", _(license[3]), "\n",  NULL);
 
-	gtk_about_dialog_set_url_hook (gpk_check_update_about_dialog_url_cb, NULL, NULL);
-	gtk_about_dialog_set_email_hook (gpk_check_update_about_dialog_url_cb, (gpointer) "mailto:", NULL);
-
 	gtk_window_set_default_icon_name (GPK_ICON_SOFTWARE_UPDATE);
 	gtk_show_about_dialog (NULL,
 			       "version", VERSION,
@@ -261,7 +221,7 @@ gpk_check_update_show_about_cb (GtkMenuItem *item, gpointer data)
 			       "wrap-license", TRUE,
 				/* TRANSLATORS: website label */
 			       "website-label", _("PackageKit Website"),
-			       "website", "www.packagekit.org",
+			       "website", "http://www.packagekit.org",
 			       "comments", "PackageKit",
 			       "authors", authors,
 			       "documenters", documenters,
@@ -457,6 +417,68 @@ out:
 		g_ptr_array_unref (array);
 }
 
+/**
+ * gpk_check_update_show_error:
+ **/
+static void
+gpk_check_update_show_error (GpkCheckUpdate *cupdate, PkError *error_code)
+{
+	gboolean ret;
+	GError *error = NULL;
+	PkErrorEnum error_enum;
+	const gchar *title;
+	const gchar *message;
+	NotifyNotification *notification = NULL;
+
+	/* ignore some errors */
+	error_enum = pk_error_get_code (error_code);
+	if (error_enum == PK_ERROR_ENUM_PROCESS_KILL)
+		goto out;
+	if (error_enum == PK_ERROR_ENUM_TRANSACTION_CANCELLED)
+		goto out;
+	if (error_enum == PK_ERROR_ENUM_CANNOT_GET_LOCK)
+		goto out;
+
+	/* get localised versions */
+	title = gpk_error_enum_to_localised_text (error_enum);
+	message = gpk_error_enum_to_localised_message (error_enum);
+
+	/* close any existing notification */
+	if (cupdate->priv->notification_error != NULL) {
+		notify_notification_close (cupdate->priv->notification_error, NULL);
+		cupdate->priv->notification_error = NULL;
+	}
+
+	/* save in case we do more details */
+	if (cupdate->priv->error_code != NULL)
+		g_object_unref (cupdate->priv->error_code);
+	cupdate->priv->error_code = g_object_ref (error_code);
+
+	/* do the bubble */
+	egg_debug ("title=%s, message=%s", title, message);
+	notification = notify_notification_new_with_status_icon (title, message, "help-browser", cupdate->priv->status_icon);
+	if (notification == NULL) {
+		egg_warning ("failed to get bubble");
+		goto out;
+	}
+	notify_notification_set_timeout (notification, 15000);
+	notify_notification_set_urgency (notification, NOTIFY_URGENCY_CRITICAL);
+	notify_notification_add_action (notification, "show-error-details",
+					/* TRANSLATORS: button: show more details about the error */
+					_("Show details"), gpk_check_update_libnotify_cb, cupdate, NULL);
+	ret = notify_notification_show (notification, &error);
+	if (!ret) {
+		egg_warning ("error: %s", error->message);
+		g_error_free (error);
+	}
+	/* track so we can prevent doubled notifications */
+	cupdate->priv->notification_error = g_object_ref (notification);
+out:
+	if (notification != NULL)
+		g_object_unref (notification);
+	return;
+}
+
 /**
  * gpk_check_update_update_system_finished_cb:
  **/
@@ -483,13 +505,7 @@ gpk_check_update_update_system_finished_cb (PkTask *task, GAsyncResult *res, Gpk
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
 		egg_warning ("failed to update system: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
-		/* ignore some errors */
-		if (pk_error_get_code (error_code) != PK_ERROR_ENUM_PROCESS_KILL &&
-		    pk_error_get_code (error_code) != PK_ERROR_ENUM_TRANSACTION_CANCELLED &&
-		    pk_error_get_code (error_code) != PK_ERROR_ENUM_CANNOT_GET_LOCK) {
-			gpk_error_dialog (gpk_error_enum_to_localised_text (pk_error_get_code (error_code)),
-					  gpk_error_enum_to_localised_message (pk_error_get_code (error_code)), pk_error_get_details (error_code));
-		}
+		gpk_check_update_show_error (cupdate, error_code);
 		goto out;
 	}
 
@@ -539,6 +555,10 @@ gpk_check_update_libnotify_cb (NotifyNotification *notification, gchar *action,
 {
 	gboolean ret;
 	GError *error = NULL;
+	const gchar *title;
+	const gchar *message;
+	const gchar *details;
+
 	GpkCheckUpdate *cupdate = GPK_CHECK_UPDATE (data);
 
 	if (g_strcmp0 (action, "do-not-show-complete-restart") == 0) {
@@ -559,9 +579,11 @@ gpk_check_update_libnotify_cb (NotifyNotification *notification, gchar *action,
 	} else if (g_strcmp0 (action, "distro-upgrade-do-not-show-available") == 0) {
 		egg_debug ("set %s to FALSE", GPK_CONF_NOTIFY_DISTRO_UPGRADES);
 		gconf_client_set_bool (cupdate->priv->gconf_client, GPK_CONF_NOTIFY_DISTRO_UPGRADES, FALSE, NULL);
-//	} else if (egg_strequal (action, "show-error-details")) {
-//		/* TRANSLATORS: detailed text about the error */
-//		gpk_error_dialog (_("Error details"), _("Package Manager error details"), cupdate->priv->error_details);
+	} else if (g_strcmp0 (action, "show-error-details") == 0) {
+		title = gpk_error_enum_to_localised_text (pk_error_get_code (cupdate->priv->error_code));
+		message = gpk_error_enum_to_localised_message (pk_error_get_code (cupdate->priv->error_code));
+		details = pk_error_get_details (cupdate->priv->error_code);
+		gpk_error_dialog (title, message, details);
 	} else if (g_strcmp0 (action, "cancel") == 0) {
 		/* try to cancel */
 		g_cancellable_cancel (cupdate->priv->cancellable);
@@ -708,10 +730,14 @@ gpk_check_update_get_best_update_icon (GpkCheckUpdate *cupdate, GPtrArray *array
 					      PK_INFO_ENUM_BUGFIX,
 					      PK_INFO_ENUM_NORMAL,
 					      PK_INFO_ENUM_ENHANCEMENT,
-					      PK_INFO_ENUM_LOW, -1);
+					      PK_INFO_ENUM_LOW,
+					      PK_INFO_ENUM_BLOCKED, -1);
 	if (value == -1) {
 		egg_warning ("should not be possible!");
 		value = PK_INFO_ENUM_LOW;
+	} else if (value == PK_INFO_ENUM_BLOCKED) {
+		/* all updates are blocked */
+		return NULL;
 	}
 
 	/* get the icon */
@@ -864,13 +890,7 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
 		egg_warning ("failed to get updates: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
-		/* ignore some errors */
-		if (pk_error_get_code (error_code) != PK_ERROR_ENUM_PROCESS_KILL &&
-		    pk_error_get_code (error_code) != PK_ERROR_ENUM_TRANSACTION_CANCELLED &&
-		    pk_error_get_code (error_code) != PK_ERROR_ENUM_CANNOT_GET_LOCK) {
-			gpk_error_dialog (gpk_error_enum_to_localised_text (pk_error_get_code (error_code)),
-					  gpk_error_enum_to_localised_message (pk_error_get_code (error_code)), pk_error_get_details (error_code));
-		}
+		gpk_check_update_show_error (cupdate, error_code);
 		goto out;
 	}
 
@@ -899,8 +919,13 @@ gpk_check_update_get_updates_finished_cb (GObject *object, GAsyncResult *res, Gp
 		g_ptr_array_add (security_array, g_strdup (pk_package_get_id (item)));
 	}
 
-	/* work out icon (cannot be NULL) */
+	/* work out icon */
 	icon = gpk_check_update_get_best_update_icon (cupdate, array);
+	if (icon == NULL) {
+		egg_debug ("all updates blocked");
+		gpk_check_update_set_icon_name (cupdate, NULL);
+		goto out;
+	}
 	gpk_check_update_set_icon_name (cupdate, icon);
 
 	/* TRANSLATORS: tooltip: how many updates are waiting to be applied */
@@ -1070,7 +1095,9 @@ gpk_check_update_query_updates (GpkCheckUpdate *cupdate)
 	}
 
 	/* get new update list */
-	pk_client_get_updates_async (PK_CLIENT(cupdate->priv->task), PK_FILTER_ENUM_NONE, cupdate->priv->cancellable, NULL, NULL,
+	pk_client_get_updates_async (PK_CLIENT(cupdate->priv->task),
+				     pk_bitfield_value (PK_FILTER_ENUM_NONE),
+				     cupdate->priv->cancellable, NULL, NULL,
 				     (GAsyncReadyCallback) gpk_check_update_get_updates_finished_cb, cupdate);
 out:
 	return;
@@ -1181,13 +1208,7 @@ gpk_check_update_refresh_cache_finished_cb (GObject *object, GAsyncResult *res,
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
 		egg_warning ("failed to refresh the cache: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
-		/* ignore some errors */
-		if (pk_error_get_code (error_code) != PK_ERROR_ENUM_PROCESS_KILL &&
-		    pk_error_get_code (error_code) != PK_ERROR_ENUM_TRANSACTION_CANCELLED &&
-		    pk_error_get_code (error_code) != PK_ERROR_ENUM_CANNOT_GET_LOCK) {
-			gpk_error_dialog (gpk_error_enum_to_localised_text (pk_error_get_code (error_code)),
-					  gpk_error_enum_to_localised_message (pk_error_get_code (error_code)), pk_error_get_details (error_code));
-		}
+		gpk_check_update_show_error (cupdate, error_code);
 		goto out;
 	}
 out:
@@ -1265,13 +1286,7 @@ gpk_check_update_get_distro_upgrades_finished_cb (GObject *object, GAsyncResult
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
 		egg_warning ("failed to get upgrades: %s, %s", pk_error_enum_to_text (pk_error_get_code (error_code)), pk_error_get_details (error_code));
-		/* ignore some errors */
-		if (pk_error_get_code (error_code) != PK_ERROR_ENUM_PROCESS_KILL &&
-		    pk_error_get_code (error_code) != PK_ERROR_ENUM_TRANSACTION_CANCELLED &&
-		    pk_error_get_code (error_code) != PK_ERROR_ENUM_CANNOT_GET_LOCK) {
-			gpk_error_dialog (gpk_error_enum_to_localised_text (pk_error_get_code (error_code)),
-					  gpk_error_enum_to_localised_message (pk_error_get_code (error_code)), pk_error_get_details (error_code));
-		}
+		gpk_check_update_show_error (cupdate, error_code);
 		goto out;
 	}
 
@@ -1434,10 +1449,12 @@ gpk_check_update_init (GpkCheckUpdate *cupdate)
 
 	cupdate->priv->updates_changed_id = 0;
 	cupdate->priv->notification_updates_available = NULL;
+	cupdate->priv->notification_error = NULL;
 	cupdate->priv->icon_name = NULL;
 	cupdate->priv->number_updates_critical_last_shown = 0;
 	cupdate->priv->status_icon = gtk_status_icon_new ();
 	cupdate->priv->cancellable = g_cancellable_new ();
+	cupdate->priv->error_code = NULL;
 
 	/* preload all the common GConf keys */
 	cupdate->priv->gconf_client = gconf_client_get_default ();
@@ -1526,8 +1543,12 @@ gpk_check_update_finalize (GObject *object)
 	g_object_unref (cupdate->priv->dbus_monitor_viewer);
 	g_object_unref (cupdate->priv->cancellable);
 	g_free (cupdate->priv->icon_name);
+	if (cupdate->priv->error_code != NULL)
+		g_object_unref (cupdate->priv->error_code);
 	if (cupdate->priv->updates_changed_id > 0)
 		g_source_remove (cupdate->priv->updates_changed_id);
+	if (cupdate->priv->notification_error != NULL)
+		g_object_unref (cupdate->priv->notification_error);
 
 	G_OBJECT_CLASS (gpk_check_update_parent_class)->finalize (object);
 }
